@@ -15,5 +15,6 @@ autoplot.LearnerRegrRpart = function(object, ...) { # nolint
         geom_boxplot(aes_string(target)),
         coord_flip(),
         theme(axis.ticks.x = element_blank(), axis.text.x = element_blank())
-    ))
+    )) +
+    ggparty::geom_node_label(aes(label = paste0("n=", .data[["nodesize"]])), nudge_y = 0.03, ids = "terminal")
 }
